@@ -1,3 +1,4 @@
+# This file imports pandas, so it should only be imported when formatting
 import numpy as np
 
 from .. import backend, config, monoid, unary
@@ -292,7 +293,7 @@ def _get_matrix_dataframe(matrix, max_rows, min_rows, max_columns, *, mask=None)
             if num_rows < nonzero._nvals:
                 df.loc["..."] = ["..."] * 3
             return df
-    return df.where(pd.notnull(df), "")
+    return df.where(pd.notna(df), "")
 
 
 def _get_vector_dataframe(vector, max_rows, min_rows, max_columns, *, mask=None):
@@ -342,7 +343,7 @@ def _get_vector_dataframe(vector, max_rows, min_rows, max_columns, *, mask=None)
             if num_rows < nonzero._nvals:
                 df.loc["..."] = ["..."] * 2
             return df
-    return df.where(pd.notnull(df), "")
+    return df.where(pd.notna(df), "")
 
 
 def get_format(x, is_transposed=False):
