@@ -109,7 +109,7 @@ class _DescriptorConfig(BaseConfig):
 
 
 def get_descriptor(**opts):
-    """Create descriptor with SuiteSparse:GraphBLAS options
+    """Create descriptor with SuiteSparse:GraphBLAS options.
 
     See SuiteSparse:GraphBLAS documentation for more details.
 
@@ -147,7 +147,7 @@ def get_descriptor(**opts):
     Descriptor or None
     """
     if not opts or all(val is False or val is None for val in opts.values()):
-        return None
+        return
     config = _DescriptorConfig()
     desc = config._parent
     if "compression" in opts or "compression_level" in opts:
@@ -162,8 +162,25 @@ def get_descriptor(**opts):
         try:
             config[key] = val
         except KeyError:
+            if key in config._enumerations:
+                values = {x for x in config._enumerations[key] if isinstance(x, (bool, str))}
+                raise ValueError(
+                    f"Invalid value for {key!r} descriptor option: {val!r}. "
+                    f"Must be one of {', '.join(repr(x) for x in sorted(values))}"
+                ) from None
+            if key in config:  # pragma: no cover (safety)
+                raise ValueError(f"Invalid value for {key!r} descriptor option") from None
+            valid = set(config) | {"compression", "compression_level"}
+            valid -= {
+                "mask_complement",
+                "mask_structure",
+                "output_replace",
+                "transpose_first",
+                "transpose_second",
+            }
             raise ValueError(
-                f"Descriptor option {key!r} not understood with suitesparse backend"
+                f"Descriptor option {key!r} not understood with suitesparse backend. "
+                f"Valid options: {', '.join(sorted(valid))}"
             ) from None
     return desc
 
