@@ -1,14 +1,19 @@
 import itertools
 import pickle
 import string
+import sys
 
 import numpy as np
 import pytest
 
+import graphblas as gb
 from graphblas import dtypes
 from graphblas.core import lib
 from graphblas.dtypes import lookup_dtype
 
+suitesparse = gb.backend == "suitesparse"
+is_win = sys.platform.startswith("win")
+
 all_dtypes = [
     dtypes.BOOL,
     dtypes.INT8,
@@ -193,7 +198,8 @@ def test_bad_register():
 
 
 def test_auto_register():
-    n = np.random.randint(10, 64)
+    rng = np.random.default_rng()
+    n = rng.integers(10, 64, endpoint=True)
     np_type = np.dtype(f"({n},)int16")
     assert lookup_dtype(np_type).np_type == np_type
 
@@ -232,3 +238,21 @@ def test_dtype_to_from_string():
                 lookup_dtype(dtype)
         else:
             assert dtype == dtype2
+
+
+def test_has_complex():
+    """Only SuiteSparse has complex (with Windows support in Python after v7.4.3.1)"""
+    if not suitesparse:
+        assert not dtypes._supports_complex
+        return
+    if not is_win:
+        assert dtypes._supports_complex
+        return
+
+    import suitesparse_graphblas as ssgb
+    from packaging.version import parse
+
+    if parse(ssgb.__version__) < parse("7.4.3.1"):
+        assert not dtypes._supports_complex
+    else:
+        assert dtypes._supports_complex
