@@ -1,27 +1,21 @@
 import numpy as np
 import pytest
 
-import graphblas as gb
 from graphblas import backend, binary, monoid
 
 from graphblas import Matrix, Vector  # isort:skip (for dask-graphblas)
 
-try:
-    # gb.io.to_numpy currently requires scipy
-    import scipy.sparse as ss
-except ImportError:  # pragma: no cover (import)
-    ss = None
-
 suitesparse = backend == "suitesparse"
 
 
-@pytest.mark.skipif("not ss or not suitesparse")
+@pytest.mark.skipif("not suitesparse")
 @pytest.mark.parametrize("method", ["scan_rowwise", "scan_columnwise"])
 @pytest.mark.parametrize("length", list(range(34)))
 @pytest.mark.parametrize("do_random", [False, True])
 def test_scan_matrix(method, length, do_random):
     if do_random:
-        A = np.random.randint(10, size=2 * length).reshape((2, length))
+        rng = np.random.default_rng()
+        A = rng.integers(10, size=2 * length).reshape((2, length))
         mask = (A % 2).astype(bool)
         A[~mask] = 0
         M = Matrix.ss.import_bitmapr(values=A, bitmap=mask, name="A")
@@ -38,7 +32,7 @@ def test_scan_matrix(method, length, do_random):
         M = M.T.new(name="A")
         R = M.ss.scan(binary.plus, order="col").T.new()
 
-    result = gb.io.to_numpy(R)
+    result = R.to_dense(0)
     try:
         np.testing.assert_array_equal(result, expected)
     except Exception:  # pragma: no cover (debug)
@@ -46,12 +40,13 @@ def test_scan_matrix(method, length, do_random):
         raise
 
 
-@pytest.mark.skipif("not ss or not suitesparse")
+@pytest.mark.skipif("not suitesparse")
 @pytest.mark.parametrize("length", list(range(34)))
 @pytest.mark.parametrize("do_random", [False, True])
 def test_scan_vector(length, do_random):
     if do_random:
-        a = np.random.randint(10, size=length)
+        rng = np.random.default_rng()
+        a = rng.integers(10, size=length)
         mask = (a % 2).astype(bool)
         a[~mask] = 0
         v = Vector.ss.import_bitmap(values=a, bitmap=mask)
@@ -62,7 +57,7 @@ def test_scan_vector(length, do_random):
         v = Vector.ss.import_full(values=a)
         expected = a.cumsum()
     r = v.ss.scan()
-    result = gb.io.to_numpy(r)
+    result = r.to_dense(0)
     try:
         np.testing.assert_array_equal(result, expected)
     except Exception:  # pragma: no cover (debug)
